/* $Id: crires_dfs.h,v 1.54 2012-10-09 08:18:01 yjung Exp $
 *
 * This file is part of the CRIRES Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: yjung $
 * $Date: 2012-10-09 08:18:01 $
 * $Revision: 1.54 $
 * $Name: not supported by cvs2svn $
 */

#ifndef CRIRES_DFS_H
#define CRIRES_DFS_H

/*-----------------------------------------------------------------------------
   								Define
 -----------------------------------------------------------------------------*/

/******************************************/
/* DEFINE HERE THE DIFFERENT COLUMN NAMES */
#define CRIRES_COL_WAVELENGTH       "Wavelength"        /* In Nanometers */
#define CRIRES_COL_WAVELENGTH_MODEL "Wavelength_model"  /* In Nanometers */
#define CRIRES_COL_EXTRACT_INT_RECT "Extracted_RECT"    /* In ADU/sec */
#define CRIRES_COL_EXTRACT_INT_OPT  "Extracted_OPT"     /* In ADU/sec */
#define CRIRES_COL_EXTRACT_ERR_RECT "Error_RECT"        /* In ADU/sec */
#define CRIRES_COL_EXTRACT_ERR_OPT  "Error_OPT"         /* In ADU/sec */
#define CRIRES_COL_EXTRACT_WN_RECT  "Weight_Norm_RECT"  /* In ADU/sec */
#define CRIRES_COL_EXTRACT_WN_OPT   "Weight_Norm_OPT"   /* In ADU/sec */
#define CRIRES_COL_EXTRACT_BG_NOISE "Background_noise"  /* In ADU/sec */
#define CRIRES_COL_CONVERSION_RECT  "Conversion_RECT"   /* In ADU/sec/Jy */
#define CRIRES_COL_CONVERSION_OPT   "Conversion_OPT"    /* In ADU/sec/Jy */
#define CRIRES_COL_THROUGHPUT       "Throughput"        /* In e-/photons */
#define CRIRES_COL_SENSITIVITY      "Sensitivity"       /* In Jy/10sigmas/hour*/
#define CRIRES_COL_STDNAME          "Std_Star_Name"     /* No Unit */
#define CRIRES_COL_RA               "Right_Ascension"   /* In degrees */
#define CRIRES_COL_DEC              "Declination"       /* In degrees */
#define CRIRES_COL_PHOTOFLUX        "Photospheric_Flux" /* In Jy */
#define CRIRES_COL_EMISSION         "Emission"          /* No Unit */
#define CRIRES_COL_DETPOSY          "Y_position"        /* In pixel */
#define CRIRES_COL_WL_DETPOSX       "Column_number"     /* In pixel */
#define CRIRES_COL_WL_POSY          "Y_Position"        /* In pixel */
#define CRIRES_CHIP_NB              "Chip Nb"           /* 1 to 4 */
#define CRIRES_COL_WL_COEFFA        "Coeff_a"       /* In Nanometers */
#define CRIRES_COL_WL_COEFFB        "Coeff_b"       /* In Nanometers/pixel */
#define CRIRES_COL_WL_COEFFC        "Coeff_c"       /* In Nanometers/pixel^2 */
#define CRIRES_COL_WL_COEFFD        "Coeff_d"       /* In Nanometers/pixel^3 */
#define CRIRES_COL_WL_COEFFE        "Coeff_e"       /* In Nanometers/pixel^4 */
#define CRIRES_COL_WL_XCORR         "XCorrelation"      /* No Unit */
#define CRIRES_COL_FWHM             "FWHM"              /* In pixel */
#define CRIRES_COL_MODEL_CONF_NAME  "Parameter_Name"    /* String */
#define CRIRES_COL_MODEL_CONF_BEST  "Best_Guess"        /* Double */
#define CRIRES_COL_MODEL_CONF_LOW   "Low_Limit"         /* Double */
#define CRIRES_COL_MODEL_CONF_HIGH  "High_Limit"        /* Double */
#define CRIRES_COL_MODEL_CONF_FLAG  "Compute_Flag"      /* Integer */
/******************************************/

/*************************************/
/* DEFINE HERE THE PRO.CATG KEYWORDS */
/* Type CRIRES_PROTYPE_SPEC_PIX */
#define CRIRES_EXTRACT_PIX_TAB          "EXTRACT_PIX_TAB"

/* Type CRIRES_PROTYPE_SPEC_WL */
#define CRIRES_ASTRO_EXTRACT_WL_TAB     "ASTRO_EXTRACT_WL_TAB"
#define CRIRES_OBS_EXTRACT_WL_TAB       "OBS_EXTRACT_WL_TAB"
#define CRIRES_OBS_WIN_EXTRACT_WL_TAB   "OBS_WIN_EXTRACT_WL_TAB"
#define CRIRES_STD_EXTRACT_WL_TAB       "STD_EXTRACT_WL_TAB"
#define CRIRES_STD_WIN_EXTRACT_WL_TAB   "STD_WIN_EXTRACT_WL_TAB"

/* Type CRIRES_PROTYPE_CONVERS */
#define CRIRES_EXTRACT_CONV_TAB         "STD_EXTRACT_CONV_TAB"
#define CRIRES_WIN_EXTRACT_CONV_TAB     "STD_WIN_EXTRACT_CONV_TAB"

/* Type CRIRES_PROTYPE_SENSIT */
#define CRIRES_EXTRACT_SENS_TAB         "STD_EXTRACT_SENS_TAB"
#define CRIRES_WIN_EXTRACT_SENS_TAB     "STD_WIN_EXTRACT_SENS_TAB"

/* Type CRIRES_PROTYPE_XCORR */
#define CRIRES_WL_XCORR_TAB             "WL_XCORR_TAB"

/* Type CRIRES_PROTYPE_FWHM */
#define CRIRES_FWHM_TAB                 "FWHM_TAB"

/* Type CRIRES_PROTYPE_WL_POLY */
#define CRIRES_CALPRO_WAVE              "CALPRO_WAVE"

/* Type CRIRES_PROTYPE_CATALOG */
#define CRIRES_CALPRO_THAR_CAT          "CALPRO_THAR_CATALOG"
#define CRIRES_CALPRO_N2O_CAT           "CALPRO_N2O_CATALOG"
#define CRIRES_CALPRO_OH_CAT            "CALPRO_OH_CATALOG"
#define CRIRES_CALPRO_HITRAN_CAT        "CALPRO_HITRAN_CATALOG"
#define CRIRES_CALPRO_MODEL_WAVEEG      "CALPRO_MODEL_WAVEEG"

/* Type CRIRES_PROTYPE_YPOS */
#define CRIRES_CALPRO_THAR_POS          "CALPRO_THAR_POS"

/* Type CRIRES_PROTYPE_PHO_FLUX */
#define CRIRES_CALPRO_STD_PHOTOFLUX     "CALPRO_STD_PHOTOFLUX"

/* Type CRIRES_PROTYPE_MOD_CONF */
#define CRIRES_CALPRO_MODEL_CONFIG      "CALPRO_MODEL_CONFIG"
#define CRIRES_CALPRO_MODEL_REFINE_CONF "CALPRO_MODEL_REFINE_CONFIG"

/* Type CRIRES_PROTYPE_PROFILE */
#define CRIRES_ASTRO_EXTRACT_PROFILE_IMA    "ASTRO_PROFILE_IMA"
#define CRIRES_STD_EXTRACT_PROFILE_IMA      "STD_PROFILE_IMA"
#define CRIRES_STD_WIN_EXTRACT_PROFILE_IMA  "STD_WIN_PROFILE_IMA"
#define CRIRES_OBS_EXTRACT_PROFILE_IMA      "OBS_PROFILE_IMA"
#define CRIRES_OBS_WIN_EXTRACT_PROFILE_IMA  "OBS_WIN_PROFILE_IMA"

/* Type CRIRES_PROTYPE_BGD_MAP */
#define CRIRES_ASTRO_EXTRACT_BGMAP_IMA      "ASTRO_BGD_MAP_IMA"
#define CRIRES_STD_EXTRACT_BGMAP_IMA        "STD_BGD_MAP_IMA"
#define CRIRES_STD_WIN_EXTRACT_BGMAP_IMA    "STD_WIN_BGD_MAP_IMA"
#define CRIRES_OBS_EXTRACT_BGMAP_IMA        "OBS_BGD_MAP_IMA"
#define CRIRES_OBS_WIN_EXTRACT_BGMAP_IMA    "OBS_WIN_BGD_MAP_IMA"

/* Type CRIRES_PROTYPE_COMBINED */
#define CRIRES_ASTRO_COMBINED_IMA       "ASTRO_COMBINED_IMA"
#define CRIRES_STD_COMBINED_IMA         "STD_COMBINED_IMA"
#define CRIRES_STD_COMBINED_NA_IMA      "STD_COMBINED_NA_IMA"
#define CRIRES_STD_COMBINED_NB_IMA      "STD_COMBINED_NB_IMA"
#define CRIRES_STD_WIN_COMBINED_IMA     "STD_WIN_COMBINED_IMA"
#define CRIRES_STD_WIN_COMBINED_NA_IMA  "STD_WIN_COMBINED_NA_IMA"
#define CRIRES_STD_WIN_COMBINED_NB_IMA  "STD_WIN_COMBINED_NB_IMA"
#define CRIRES_OBS_COMBINED_IMA         "OBS_COMBINED_IMA"
#define CRIRES_OBS_COMBINED_NA_IMA      "OBS_COMBINED_NA_IMA"
#define CRIRES_OBS_COMBINED_NB_IMA      "OBS_COMBINED_NB_IMA"
#define CRIRES_OBS_WIN_COMBINED_IMA     "OBS_WIN_COMBINED_IMA"
#define CRIRES_OBS_WIN_COMBINED_NA_IMA  "OBS_WIN_COMBINED_NA_IMA"
#define CRIRES_OBS_WIN_COMBINED_NB_IMA  "OBS_WIN_COMBINED_NB_IMA"

/* Type CRIRES_PROTYPE_CONTRIB */
#define CRIRES_ASTRO_CONTRIBUTION_IMA   "ASTRO_CONTRIBUTION_IMA"
#define CRIRES_STD_CONTRIBUTION_IMA     "STD_CONTRIBUTION_IMA"
#define CRIRES_STD_CONTRIBUTION_NA_IMA  "STD_CONTRIBUTION_NA_IMA"
#define CRIRES_STD_CONTRIBUTION_NB_IMA  "STD_CONTRIBUTION_NB_IMA"
#define CRIRES_STD_WIN_CONTRIBUTION_IMA "STD_WIN_CONTRIBUTION_IMA"
#define CRIRES_STD_WIN_CONTRIBUTION_NA_IMA "STD_WIN_CONTRIBUTION_NA_IMA"
#define CRIRES_STD_WIN_CONTRIBUTION_NB_IMA "STD_WIN_CONTRIBUTION_NB_IMA"
#define CRIRES_OBS_CONTRIBUTION_IMA     "OBS_CONTRIBUTION_IMA"
#define CRIRES_OBS_CONTRIBUTION_NA_IMA  "OBS_CONTRIBUTION_NA_IMA"
#define CRIRES_OBS_CONTRIBUTION_NB_IMA  "OBS_CONTRIBUTION_NB_IMA"
#define CRIRES_OBS_WIN_CONTRIBUTION_IMA "OBS_WIN_CONTRIBUTION_IMA"
#define CRIRES_OBS_WIN_CONTRIBUTION_NA_IMA "OBS_WIN_CONTRIBUTION_NA_IMA"
#define CRIRES_OBS_WIN_CONTRIBUTION_NB_IMA "OBS_WIN_CONTRIBUTION_NB_IMA"

/* Type CRIRES_PROTYPE_WL_MAP */
#define CRIRES_ASTRO_WL_MAP_IMA         "ASTRO_WL_MAP_IMA"
#define CRIRES_ASTRO_WL_MAP_MODEL_IMA   "ASTRO_WL_MAP_MODEL_IMA"
#define CRIRES_OBS_WL_MAP_IMA           "OBS_WL_MAP_IMA"
#define CRIRES_OBS_WIN_WL_MAP_IMA       "OBS_WIN_WL_MAP_IMA"
#define CRIRES_STD_WL_MAP_IMA           "STD_WL_MAP_IMA"
#define CRIRES_STD_WIN_WL_MAP_IMA       "STD_WIN_WL_MAP_IMA"
#define CRIRES_OBS_WL_MAP_MODEL_IMA     "OBS_WL_MAP_MODEL_IMA"
#define CRIRES_OBS_WIN_WL_MAP_MODEL_IMA "OBS_WIN_WL_MAP_MODEL_IMA"
#define CRIRES_STD_WL_MAP_MODEL_IMA     "STD_WL_MAP_MODEL_IMA"
#define CRIRES_STD_WIN_WL_MAP_MODEL_IMA "STD_WIN_WL_MAP_MODEL_IMA"
#define CRIRES_WL_MAP_MODEL_IMA         "WL_MAP_MODEL_IMA"
#define CRIRES_WL_MAP_IMA               "WL_MAP_IMA"

/* Type CRIRES_PROTYPE_DARK */
#define CRIRES_CALPRO_DARK              "CALPRO_DARK"
#define CRIRES_CALPRO_DARK_WIN          "CALPRO_DARK_WIN"

/* Type CRIRES_PROTYPE_FLAT */
#define CRIRES_CALPRO_FLAT              "CALPRO_FLAT"
#define CRIRES_CALPRO_FLAT_WIN          "CALPRO_FLAT_WIN"

/* Type CRIRES_PROTYPE_BPM */
#define CRIRES_CALPRO_BPM               "CALPRO_BPM"
#define CRIRES_CALPRO_BPM_WIN           "CALPRO_BPM_WIN"

/**************************   DETMON PRODUCTS   ******************************/

/* Type CRIRES_PROTYPE_COEFFS_CUBE */
#define CRIRES_CALPRO_COEFFS_CUBE       "COEFFS_CUBE"

/* Type CRIRES_PROTYPE_BP_MAP_NL */
#define CRIRES_CALPRO_DETMON_BPM        "BP_MAP_NL"

/* Type CRIRES_PROTYPE_GAIN_STATS */
#define CRIRES_CALPRO_DETMON_GAIN       "GAIN_INFO"

/* Type CRIRES_PROTYPE_DETLIN_INFO */
#define CRIRES_CALPRO_DETLIN_INFO       "DET_LIN_INFO"

/*****************************************************************************/

/* Type CRIRES_TXT_MODEL_FIX_TAB */
#define CRIRES_CALPRO_MODEL_FIX_TAB     "CALPRO_MODEL_FIX_TAB"

/*************************************/

/*************************************/
/* Define here the PRO.TYPE keywords */
/* Images */
#define CRIRES_PROTYPE_PROFILE      "PROFILE"
#define CRIRES_PROTYPE_BGD_MAP      "BGD_MAP"
#define CRIRES_PROTYPE_COMBINED     "COMBINED"
#define CRIRES_PROTYPE_CONTRIB      "CONTRIB"
#define CRIRES_PROTYPE_WL_MAP       "WL_MAP"
#define CRIRES_PROTYPE_DARK         "DARK"
#define CRIRES_PROTYPE_FLAT         "FLAT"
#define CRIRES_PROTYPE_BPM          "BPM"
#define CRIRES_PROTYPE_COEFFS_CUBE  "REDUCED"
#define CRIRES_PROTYPE_BP_MAP_NL    "REDUCED"
#define CRIRES_PROTYPE_DETLIN_INFO  "REDUCED"

/* Tables */
/* Col: CRIRES_COL_EXTRACT_INT_RECT */
/*      CRIRES_COL_EXTRACT_INT_OPT  */
/*      CRIRES_COL_EXTRACT_ERR_RECT */
/*      CRIRES_COL_EXTRACT_ERR_OPT  */
/*      CRIRES_COL_EXTRACT_WN_RECT  */
/*      CRIRES_COL_EXTRACT_WN_OPT   */
/*      CRIRES_COL_EXTRACT_BG_NOISE */
#define CRIRES_PROTYPE_SPEC_PIX     "SPEC_PIX"
/* Col: CRIRES_COL_EXTRACT_INT_RECT */
/*      CRIRES_COL_EXTRACT_INT_OPT  */
/*      CRIRES_COL_EXTRACT_ERR_RECT */
/*      CRIRES_COL_EXTRACT_ERR_OPT  */
/*      CRIRES_COL_EXTRACT_WN_RECT  */
/*      CRIRES_COL_EXTRACT_WN_OPT   */
/*      CRIRES_COL_EXTRACT_BG_NOISE */
/*      CRIRES_COL_WAVELENGTH       */
/*      CRIRES_COL_WAVELENGTH_MODEL */
#define CRIRES_PROTYPE_SPEC_WL      "SPEC_WL"
/* Col: CRIRES_COL_EXTRACT_INT_RECT */
/*      CRIRES_COL_EXTRACT_INT_OPT  */
/*      CRIRES_COL_EXTRACT_ERR_RECT */
/*      CRIRES_COL_EXTRACT_ERR_OPT  */
/*      CRIRES_COL_EXTRACT_WN_RECT  */
/*      CRIRES_COL_EXTRACT_WN_OPT   */
/*      CRIRES_COL_EXTRACT_BG_NOISE */
/*      CRIRES_COL_WAVELENGTH       */
/*      CRIRES_COL_WAVELENGTH_MODEL */
/*      CRIRES_COL_CONVERSION_RECT  */
/*      CRIRES_COL_CONVERSION_OPT   */
/*      CRIRES_COL_THROUGHPUT       */
#define CRIRES_PROTYPE_CONVERS      "CONVERS"
/* Col: CRIRES_COL_EXTRACT_INT_RECT */
/*      CRIRES_COL_EXTRACT_INT_OPT  */
/*      CRIRES_COL_EXTRACT_ERR_RECT */
/*      CRIRES_COL_EXTRACT_ERR_OPT  */
/*      CRIRES_COL_EXTRACT_WN_RECT  */
/*      CRIRES_COL_EXTRACT_WN_OPT   */
/*      CRIRES_COL_EXTRACT_BG_NOISE */
/*      CRIRES_COL_WAVELENGTH       */
/*      CRIRES_COL_WAVELENGTH_MODEL */
/*      CRIRES_COL_CONVERSION_RECT  */
/*      CRIRES_COL_CONVERSION_OPT   */
/*      CRIRES_COL_THROUGHPUT       */
/*      CRIRES_COL_SENSITIVITY      */
#define CRIRES_PROTYPE_SENSIT       "SENSIT"

/* Col: IRPLIB_WLXCORR_COL_WAVELENGTH   */
/*      IRPLIB_WLXCORR_COL_CAT_INIT     */
/*      IRPLIB_WLXCORR_COL_CAT_FINAL    */
/*      IRPLIB_WLXCORR_COL_OBS          */
#define CRIRES_PROTYPE_XCORR        "XCORR"

/* Col: CRIRES_COL_WL_DETPOSX   */
/*      CRIRES_COL_DETPOSY      */
/*      CRIRES_COL_FWHM         */
#define CRIRES_PROTYPE_FWHM         "FWHM"

/* Col: CRIRES_COL_WL_POSY      */
/*      CRIRES_COL_WL_COEFFA    */
/*      CRIRES_COL_WL_COEFFB    */
/*      CRIRES_COL_WL_COEFFC    */
/*      CRIRES_COL_WL_COEFFD    */
/*      CRIRES_COL_WL_COEFFE    */
/*      CRIRES_COL_WL_XCORR     */
#define CRIRES_PROTYPE_WL_POLY      "WL_POLY"

/* Col: CRIRES_COL_WAVELENGTH   */
/*      CRIRES_COL_EMISSION     */
#define CRIRES_PROTYPE_CATALOG      "CATALOG"

/* Col: CRIRES_CHIP_NB          */
/*      CRIRES_COL_DETPOSY      */
#define CRIRES_PROTYPE_YPOS         "YPOS"

/* Col: CRIRES_COL_STDNAME      */
/*      CRIRES_COL_RA           */
/*      CRIRES_COL_DEC          */
/*      CRIRES_COL_PHOTOFLUX    */
#define CRIRES_PROTYPE_PHO_FLUX     "PHO_FLUX"

/* Col: CRIRES_COL_MODEL_CONF_NAME  */
/*      CRIRES_COL_MODEL_CONF_BEST  */
/*      CRIRES_COL_MODEL_CONF_LOW   */
/*      CRIRES_COL_MODEL_CONF_HIGH  */
/*      CRIRES_COL_MODEL_CONF_FLAG  */
#define CRIRES_PROTYPE_MOD_CONF     "MOD_CONF"

/* Col: Defined in detmonp  */
#define CRIRES_PROTYPE_LIN_STATS    "LIN_STATS"

/* Col: Defined in detmonp  */
#define CRIRES_PROTYPE_GAIN_STATS   "REDUCED"

/* TXT file with 4 columns: Xpix Ypix chip WL */
#define CRIRES_TXT_MODEL_FIX_TAB    "TXT_MODEL_FIX_TAB"

/*************************************/

/************************************/
/* Define here the DO.CATG keywords */

#define CRIRES_UTIL_GENCONFIG_RAW       "CONFIG"
#define CRIRES_UTIL_GENLINES_RAW        "CATALOG"
#define CRIRES_UTIL_GENYPOS_RAW         "YPOS"
#define CRIRES_UTIL_GENSTD_RAW          "STDSTAR"
#define CRIRES_COMMAND_LINE             "COMMAND_LINE"

#define CRIRES_MODEL_WLMAP_RAW          "MODEL_WLMAP_RAW"
#define CRIRES_MODEL_FIX_RAW            "MODEL_FIX_RAW"
#define CRIRES_MODEL_REFINE_RAW         "MODEL_REFINE_RAW"
#define CRIRES_SPEC_JITTER_RAW          "OBS_DIR"
#define CRIRES_WIN_JITTER_RAW           "OBS_DIR_WIN"
#define CRIRES_SPEC_JITTER_J_RAW        "OBS_DIR_JIT"
#define CRIRES_WIN_JITTER_J_RAW         "OBS_DIR_JIT_WIN"
#define CRIRES_SPEC_NODDING_OBJECT_RAW  "OBS_OBJECT"
#define CRIRES_WIN_NODDING_OBJECT_RAW   "OBS_OBJECT_WIN"
#define CRIRES_SPEC_GENERIC_OBJECT_RAW  "OBS_GENERIC_OBJECT"
#define CRIRES_SPEC_NODDING_SKY_RAW     "OBS_SKY"
#define CRIRES_WIN_NODDING_SKY_RAW      "OBS_SKY_WIN"
#define CRIRES_SPEC_GENERIC_SKY_RAW     "OBS_GENERIC_SKY"
#define CRIRES_SPEC_NODDING_RAW         "OBS_NOD"
#define CRIRES_WIN_NODDING_RAW          "OBS_NOD_WIN"
#define CRIRES_SPEC_NODDING_J_RAW       "OBS_NOD_JIT"
#define CRIRES_WIN_NODDING_J_RAW        "OBS_NOD_JIT_WIN"
#define CRIRES_SPEC_ASTRO_RAW           "ASTRO_NOD_JIT"
#define CRIRES_SPEC_DARK_RAW            "CAL_DARK"
#define CRIRES_WIN_DARK_RAW             "CAL_DARK_WIN"
#define CRIRES_SPEC_FLAT_RAW            "CAL_FLAT"
#define CRIRES_WIN_FLAT_RAW             "CAL_FLAT_WIN"
#define CRIRES_SPEC_WAVECAL_SKY_RAW     "CAL_WLSKY"
#define CRIRES_SPEC_WAVECAL_LAMP_RAW    "CAL_WLLAMP"
#define CRIRES_SPEC_WAVECAL_ABS_RAW     "CAL_WLABS"
#define CRIRES_SPEC_JITTER_STD_RAW      "CAL_DIR"
#define CRIRES_SPEC_JITTER_J_STD_RAW    "CAL_DIR_JIT"
#define CRIRES_SPEC_NODDING_STD_RAW     "CAL_NOD"
#define CRIRES_WIN_NODDING_STD_RAW      "CAL_NOD_WIN"
#define CRIRES_SPEC_NODDING_J_STD_RAW   "CAL_NOD_JIT"
#define CRIRES_WIN_NODDING_J_STD_RAW    "CAL_NOD_JIT_WIN"
/************************************/

/*-----------------------------------------------------------------------------
                                Functions prototypes
 -----------------------------------------------------------------------------*/

int crires_dfs_set_groups(cpl_frameset *, const char *) ;

#endif
